@@ -169,7 +169,7 @@ def basic_subscriber():
 
 @pytest.mark.flaky(reruns=5)
 @pytest.mark.serial
-def test_basic_subscription(experiment, basic_subscriber):
+def test_subscription_on_dual_datasets(experiment, basic_subscriber):
     xparam = ParamSpecBase(name='x',
                            paramtype='numeric',
                            label='x parameter',
@@ -230,8 +230,8 @@ def test_basic_subscription(experiment, basic_subscriber):
     dataset1.unsubscribe(sub_id_1)
     dataset2.unsubscribe(sub_id_2)
 
-    assert len(dataset2.subscribers) == 0
-    assert list(dataset2.subscribers.keys()) == []
+    assert len(dataset1.subscribers) == 0
+    assert list(dataset1.subscribers.keys()) == []
 
     assert len(dataset2.subscribers) == 0
     assert list(dataset2.subscribers.keys()) == []
